iris-grib
=========

|Travis|_ |Coveralls|_

GRIB interface for `Iris <https://github.com/SciTools/iris>`_.

Code
----
iris-grib is licenced under the GNU Lesser General Public License (LGPLv3).

The full text of the licence can be found in the COPYING and COPYING.LESSER
files.

Copyright and licence
---------------------
iris-grib may be freely distributed, modified and used commercially under the
terms of its `GNU LGPLv3 license <COPYING.LESSER>`_.

\(C) British Crown Copyright 2010 - 2019, Met Office

.. |Travis| image:: https://travis-ci.org/SciTools/iris-grib.svg?branch=master
.. _Travis: https://travis-ci.org/SciTools/iris-grib

.. |Coveralls| image:: https://coveralls.io/repos/github/SciTools/iris-grib/badge.svg?branch=master
.. _Coveralls: https://coveralls.io/github/SciTools/iris-grib?branch=master 
